==> scalatest_2.11-2.1.3-sources.jar: org/scalatest/words/ResultOfMessageWordApplication.scala <==
/*
 * Copyright 2001-2013 Artima, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.scalatest.words

import org.scalatest.enablers.Messaging
import org.scalatest.matchers.HavePropertyMatcher
import org.scalatest.matchers.HavePropertyMatchResult
import org.scalautils.Prettifier

/**
 * This class is part of the ScalaTest matchers DSL. Please see the documentation for <a href="../Matchers.html"><code>Matchers</code></a> for an overview of
 * the matchers DSL.
 *
 * @author Bill Venners
 * @author Chee Seng
 */
final class ResultOfMessageWordApplication(val expectedMessage: String) {

  def apply[T : Messaging](resultOfOfTypeInvocation: ResultOfOfTypeInvocation[T]): HavePropertyMatcher[T, String] = {
    new HavePropertyMatcher[T, String] {
      def apply(t: T): HavePropertyMatchResult[String] = {
        val messaging = implicitly[Messaging[T]]
        val messageOfT = messaging.messageOf(t)
        new HavePropertyMatchResult(
          messageOfT == expectedMessage,
          "message",
           expectedMessage,
           messageOfT
        )
      }
    }
  }
  
  /**
   * Overrides toString to return "message (\"XXX\")", where XXX is expectedMessage
   */
  override def toString: String = "message (" + Prettifier.default(expectedMessage) + ")"
}

==> scalatest_2.12-3.0.5-sources.jar: org/scalatest/words/ResultOfMessageWordApplication.scala <==
/*
 * Copyright 2001-2013 Artima, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.scalatest.words

import org.scalatest.enablers.Messaging
import org.scalatest.matchers.HavePropertyMatcher
import org.scalatest.matchers.HavePropertyMatchResult
import org.scalactic.Prettifier

/**
 * This class is part of the ScalaTest matchers DSL. Please see the documentation for <a href="../Matchers.html"><code>Matchers</code></a> for an overview of
 * the matchers DSL.
 *
 * @author Bill Venners
 * @author Chee Seng
 */
final class ResultOfMessageWordApplication(val expectedMessage: String) {

  // TODO: SCALADOC
  def apply[T : Messaging](resultOfOfTypeInvocation: ResultOfOfTypeInvocation[T]): HavePropertyMatcher[T, String] = {
    new HavePropertyMatcher[T, String] {
      def apply(t: T): HavePropertyMatchResult[String] = {
        val messaging = implicitly[Messaging[T]]
        val messageOfT = messaging.messageOf(t)
        new HavePropertyMatchResult(
          messageOfT == expectedMessage,
          "message",
           expectedMessage,
           messageOfT
        )
      }
    }
  }
  
  /**
   * Overrides toString to return "message (\"XXX\")", where XXX is expectedMessage
   */
  override def toString: String = "message (" + Prettifier.default(expectedMessage) + ")"
}
